==> haskell-adjunctions-4.4.3-96.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.3
visibility:           public
id:                   adjunctions-4.4.3-JFB4iJ93aO845aovoP0TqZ
key:                  adjunctions-4.4.3-JFB4iJ93aO845aovoP0TqZ
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  504985b8233c6384c46620ca49c1d4f5
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.3-JFB4iJ93aO845aovoP0TqZ
depends:
    array-0.5.6.0 base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
    containers-0.6.7 contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    free-5.2-3fckYVSYEwRA3sQVkSQiQV mtl-2.3.1
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4.3-97-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.3
visibility:           public
id:                   adjunctions-4.4.3-CGfiZ0Nwp52HytI706XQqX
key:                  adjunctions-4.4.3-CGfiZ0Nwp52HytI706XQqX
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  c723973ed2e8146f289cef3b80b85cfb
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.3-CGfiZ0Nwp52HytI706XQqX
depends:
    array-0.5.6.0 base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
    containers-0.6.7 contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    free-5.2-CP2SAI6deNWCXG1eD5QmMc mtl-2.3.1
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
